@@ -1059,7 +1059,7 @@ gnutls_openpgp_privkey_get_preferred_key_id (gnutls_openpgp_privkey_t key,
       return GNUTLS_E_INVALID_REQUEST;
     }
 
-  memcpy( keyid, key->preferred_keyid, sizeof(keyid));
+  memcpy( keyid, key->preferred_keyid, sizeof(gnutls_openpgp_keyid_t));
 
   return 0;
 }
@@ -1096,7 +1096,7 @@ gnutls_openpgp_privkey_set_preferred_key_id (gnutls_openpgp_privkey_t key,
     }
 
   key->preferred_set = 1;
-  memcpy( key->preferred_keyid, keyid, sizeof(keyid));
+  memcpy( key->preferred_keyid, keyid, sizeof(gnutls_openpgp_keyid_t));
 
   return 0;
 }
